@@ -30,23 +30,30 @@ from .. import utils as ciecplib_utils
 __author__ = 'Duncan Macleod <duncan.macleod@ligo.org>'
 
 # mock response from ECP IdP list
-INSTITUTIONS = {
-    "Institution 1": "https://inst1.test",
-    "Institution 1 (Kerberos)": "https://inst1.test.krb",
-    "Institution 2": "https://inst2.test",
+INST_DICT = {
+    "Institution 1": "https://inst1.test/idp/profile/SAML2/SOAP/ECP",
+    "Institution 1 (Kerberos)":
+        "https://inst1.test.krb/idp-krb/profile/SAML2/SOAP/ECP",
+    "Institution 2": "https://inst2.test/idp/profile/SAML2/SOAP/ECP",
 }
-RAW_IDP_LIST = "\n".join(
-    (" ".join((y, x)) for (x, y) in INSTITUTIONS.items()),
-).encode()
+INSTITUTIONS = [
+    ciecplib_utils.EcpIdentityProvider(
+        name,
+        url,
+        name.endswith("(Kerberos)"),
+    ) for name, url in INST_DICT.items()
+]
+RAW_IDP_LIST = "\n".join(map("{0.url} {0.name}".format, INSTITUTIONS)).encode()
 
 
 @mock.patch(
     "os.getlogin" if os.name == "nt" else "os.getuid",
     mock.MagicMock(return_value=123),
 )
+@mock.patch.dict("os.environ")
 def test_get_ecpcookie_path():
     if os.name == "nt":
-        path = r"%SYSTEMROOT%\Temp\ecpcookie.123"
+        path = r"C:\WINDOWS\Temp\ecpcookie.123"
     else:
         path = "/tmp/ecpcookie.u123"
     assert ciecplib_utils.get_ecpcookie_path() == Path(path)
@@ -57,8 +64,9 @@ def test_get_ecpcookie_path():
     mock.MagicMock(return_value=123),
 )
 def test_get_x509_proxy_path():
+    os.environ.pop("X509_USER_PROXY", None)
     if os.name == "nt":
-        path = r"%SYSTEMROOT%\Temp\x509up_123"
+        path = r"C:\WINDOWS\Temp\x509up_123"
     else:
         path = "/tmp/x509up_u123"
     assert ciecplib_utils.get_x509_proxy_path() == Path(path)
@@ -69,37 +77,30 @@ def test_get_idps(requests_mock):
     assert ciecplib_utils.get_idps("https://idp-list-url") == INSTITUTIONS
 
 
-@pytest.mark.parametrize("inst, result", [
-    ("Institution 1", (
-        INSTITUTIONS["Institution 1"],
-        INSTITUTIONS["Institution 1 (Kerberos)"],
-    )),
-    ("Institution 2", (INSTITUTIONS["Institution 2"],) * 2),
+@pytest.mark.parametrize("value, krb, result", [
+    ("Institution 1", False, INST_DICT["Institution 1"]),
+    ("Institution 1 (Kerberos)", None,
+     INST_DICT["Institution 1 (Kerberos)"]),
+    ("Institution 1", True, INST_DICT["Institution 1 (Kerberos)"]),
+    ("inst1", False, INST_DICT["Institution 1"]),
+    ("inst1.test.krb", None, INST_DICT["Institution 1 (Kerberos)"]),
+    ("inst2", None, INST_DICT["Institution 2"]),
 ])
-def test_get_idp_urls(requests_mock, inst, result):
+def test_get_idp_url(requests_mock, value, krb, result):
     requests_mock.get("https://idp-list-url", content=RAW_IDP_LIST)
-    assert ciecplib_utils.get_idp_urls(
-        inst,
-        url="https://idp-list-url",
+    assert ciecplib_utils.get_idp_url(
+        value,
+        idplist_url="https://idp-list-url",
+        kerberos=krb,
     ) == result
 
 
-@pytest.mark.parametrize("inst", ["Institution*", "something else"])
-def test_get_idp_urls_error(requests_mock, inst):
+@pytest.mark.parametrize("inst", [
+    "Institution*",
+    "test",
+    "something else",
+])
+def test_get_idp_url_error(requests_mock, inst):
     requests_mock.get("https://idp-list-url", content=RAW_IDP_LIST)
     with pytest.raises(ValueError):
-        ciecplib_utils.get_idp_urls(inst, url="https://idp-list-url")
-
-
-@pytest.mark.parametrize("url, result", [
-    ("login.ligo.org",
-     "https://login.ligo.org/idp/profile/SAML2/SOAP/ECP"),
-    ("https://login.ligo.org",
-     "https://login.ligo.org/idp/profile/SAML2/SOAP/ECP"),
-    ("login.ligo.org/test",
-     "https://login.ligo.org/test"),
-    ("https://login.ligo.org/idp/profile/SAML2/SOAP/ECP",
-     "https://login.ligo.org/idp/profile/SAML2/SOAP/ECP"),
-])
-def test_format_endpoint_url(url, result):
-    assert ciecplib_utils.format_endpoint_url(url) == result
+        ciecplib_utils.get_idp_url(inst, idplist_url="https://idp-list-url")
